@@ -32,7 +32,6 @@ INSTALLED_APPS = (
     'django.contrib.staticfiles',
     'django.contrib.messages',
     'django.contrib.humanize',
-    'django_nose',
     'openstack_auth',
     'compressor',
     'horizon',
@@ -119,14 +118,6 @@ SECURITY_GROUP_RULES = {
     },
 }
 
-NOSE_ARGS = ['--nocapture',
-             '--nologcapture',
-             '--cover-package=monitoring',
-             '--cover-inclusive',
-             '--with-xunit',
-             '--all-modules']
-
-
 OPENSTACK_SSL_NO_VERIFY = False
 
 OPENSTACK_SSL_CACERT = '/etc/ssl/certs/some2.crt'
